@@ -67,7 +67,8 @@ COMMENT_DELIMITER_INFO = {
     "Go":             ( ( "//", ),     "/*",            "*/"),
     "JavaScript":     ( ( "//", ),     "/*",            "*/"),
     "Objective-C":    ( ( "//", ),     "/*",            "*/"),
-    "Rust":           ( ( "//", ),     "/*",            "*/"),
+    #  Support Rust comments (``//``) as well as `Rustdoc <https://doc.rust-lang.org/rustdoc/what-is-rustdoc.html#outer-and-inner-documentation>`_.
+    "Rust":           ( ( "//", "///", "//!"), "/*",    "*/"),
     "Scala":          ( ( "//", ),     "/*",            "*/"),
     "Swift":          ( ( "//", ),     "/*",            "*/"),
     "verilog":        ( ( "//", ),     "/*",            "*/"),
@@ -111,7 +112,8 @@ COMMENT_DELIMITER_INFO = {
     "PL/pgSQL":       ( ( "--", ),     "/*",            "*/"),
     "PowerShell":     ( ( "#", ),      "<#",            "#>"),
     # ``/*`` ~ ``*/`` not supported (Pygments doesn't lex these).
-    "GAS":            ( ( "#", ),      "/*",            "*/"),
+    "GAS":            ( ( "#", ";" ),  "/*",            "*/"),
+    "ARM":            ( ( "#", ";", "@"), "/*",         "*/"),
     "autohotkey":     ( ( ";", ),      "/*",            "*/"),
     "Prolog":         ( ( "%", ),      "/*",            "*/"),
     "AutoIt":         ( ( ";", ),     "#cs",           "#ce"),
@@ -158,6 +160,11 @@ COMMENT_DELIMITER_INFO = {
     "COBOL":          ( ( "      *", ),  "",              ""),
     "YAML":           ( ( "#", ),        "",              ""),
     "TOML":           ( ( "#", ),        "",              ""),
+    "Mako":           ( ( "##", ), "<%doc>",       "</%doc>"),
+    "HTML+Mako":      ( ( "##", ), "<%doc>",       "</%doc>"),
+    "XML+Mako":       ( ( "##", ), "<%doc>",       "</%doc>"),
+    "JavaScript+Mako": ( ( "##", ), "<%doc>",      "</%doc>"),
+    "CSS+Mako":       ( ( "##", ), "<%doc>",       "</%doc>"),
 
 # These languages lack unit tests
 # -------------------------------
